From 27b0c159a2297ede9a9c33b1e970a3e1c10fa50e Mon Sep 17 00:00:00 2001
From: Dinesh Solanki <15937452+dineshsolanki@users.noreply.github.com>
Date: Wed, 24 Jul 2024 14:12:11 +0530
Subject: [PATCH] Rename "Extract manually" to "Extract gallery"
---
FoliCon/Modules/LangProvider.cs | 6 +++---
FoliCon/Properties/Langs/Lang.Designer.cs | 12 ++++++------
FoliCon/Properties/Langs/Lang.ar.resx | 4 ++--
FoliCon/Properties/Langs/Lang.es.resx | 4 ++--
FoliCon/Properties/Langs/Lang.hi.resx | 2 +-
FoliCon/Properties/Langs/Lang.pt.resx | 4 ++--
FoliCon/Properties/Langs/Lang.resx | 4 ++--
FoliCon/Properties/Langs/Lang.ru.resx | 4 ++--
8 files changed, 20 insertions(+), 20 deletions(-)
diff --git a/FoliCon/Modules/LangProvider.cs b/FoliCon/Modules/LangProvider.cs
index fe76cd8..e61d0d8 100644
--- a/FoliCon/Modules/LangProvider.cs
+++ b/FoliCon/Modules/LangProvider.cs
@@ -89,7 +89,7 @@ private void UpdateLangs()
OnPropertyChanged(nameof(EnterTitlePlaceholder));
OnPropertyChanged(nameof(EnterValidRegexPlaceholder));
OnPropertyChanged(nameof(ExplorerIntegration));
- OnPropertyChanged(nameof(ExtractManually));
+ OnPropertyChanged(nameof(ExtractGallery));
OnPropertyChanged(nameof(Extracting));
OnPropertyChanged(nameof(FailedFileAccessAt));
OnPropertyChanged(nameof(FailedToSaveMediaInfoAt));
@@ -265,7 +265,7 @@ private void UpdateLangs()
public string EnterValidRegexPlaceholder => Lang.EnterValidRegexPlaceholder;
public string ExceptionOccurred => Lang.ExceptionOccurred;
public string ExplorerIntegration => Lang.ExplorerIntegration;
- public string ExtractManually => Lang.ExtractManually;
+ public string ExtractGallery => Lang.ExtractGallery;
public string Extracting => Lang.Extracting;
public string FailedFileAccessAt => Lang.FailedFileAccessAt;
public string FailedToSaveMediaInfoAt => Lang.FailedToSaveMediaInfoAt;
@@ -449,7 +449,7 @@ public class LangKeys
public static string EnterValidRegexPlaceholder = nameof(EnterValidRegexPlaceholder);
public static string ExceptionOccurred = nameof(ExceptionOccurred);
public static string ExplorerIntegration = nameof(ExplorerIntegration);
- public static string ExtractManually = nameof(ExtractManually);
+ public static string ExtractGallery = nameof(ExtractGallery);
public static string Extracting = nameof(Extracting);
public static string FailedFileAccessAt = nameof(FailedFileAccessAt);
public static string FailedToSaveMediaInfoAt = nameof(FailedToSaveMediaInfoAt);
diff --git a/FoliCon/Properties/Langs/Lang.ar.resx b/FoliCon/Properties/Langs/Lang.ar.resx
index a2ac4ab..61553b6 100644
--- a/FoliCon/Properties/Langs/Lang.ar.resx
+++ b/FoliCon/Properties/Langs/Lang.ar.resx
@@ -648,8 +648,8 @@
المستكشف اليدوي
-
- استخراج يدوي
+
+ استخراج المعرض
جارٍ الاستخراج...
diff --git a/FoliCon/Properties/Langs/Lang.es.resx b/FoliCon/Properties/Langs/Lang.es.resx
index 5c16318..07c7f6a 100644
--- a/FoliCon/Properties/Langs/Lang.es.resx
+++ b/FoliCon/Properties/Langs/Lang.es.resx
@@ -648,8 +648,8 @@ Esto ayuda a folicon a identificar los medios sin tener que elegir entre título
Explorador manual
-
- Extraer manualmente
+
+ Extraer galería
Extrayendo...
diff --git a/FoliCon/Properties/Langs/Lang.hi.resx b/FoliCon/Properties/Langs/Lang.hi.resx
index f70824d..165ab2e 100644
--- a/FoliCon/Properties/Langs/Lang.hi.resx
+++ b/FoliCon/Properties/Langs/Lang.hi.resx
@@ -648,7 +648,7 @@
मैनुअल एक्सप्लोरर
-
+
एक्सट्रेक्ट करे
diff --git a/FoliCon/Properties/Langs/Lang.pt.resx b/FoliCon/Properties/Langs/Lang.pt.resx
index 5f52611..3b84164 100644
--- a/FoliCon/Properties/Langs/Lang.pt.resx
+++ b/FoliCon/Properties/Langs/Lang.pt.resx
@@ -647,8 +647,8 @@ e renovar o cache dos Ícones?
Explorador manual
-
- Extrair manualmente
+
+ Extrair galeria
Extraindo...
diff --git a/FoliCon/Properties/Langs/Lang.resx b/FoliCon/Properties/Langs/Lang.resx
index c3283c8..dc66b76 100644
--- a/FoliCon/Properties/Langs/Lang.resx
+++ b/FoliCon/Properties/Langs/Lang.resx
@@ -652,8 +652,8 @@ and refresh Icon Cache?
Manual Explorer
-
- Extract manually
+
+ Extract gallery
Extracting...
diff --git a/FoliCon/Properties/Langs/Lang.ru.resx b/FoliCon/Properties/Langs/Lang.ru.resx
index 64eb3c3..75cdec4 100644
--- a/FoliCon/Properties/Langs/Lang.ru.resx
+++ b/FoliCon/Properties/Langs/Lang.ru.resx
@@ -651,8 +651,8 @@
Ручной проводник
-
- Извлечь вручную
+
+ Извлечь галерею
Извлечение...
diff --git a/FoliCon/Properties/Langs/Lang.Designer.cs b/FoliCon/Properties/Langs/Lang.Designer.cs
index 1b42aff..35519a2 100644
--- a/FoliCon/Properties/Langs/Lang.Designer.cs
+++ b/FoliCon/Properties/Langs/Lang.Designer.cs
@@ -583,20 +583,20 @@ public static string ExplorerIntegration {
}
///
/// Looks up a localized string similar to Extracting....
///
- public static string Extracting {
+ public static string ExtractGallery {
get {
- return ResourceManager.GetString("Extracting", resourceCulture);
+ return ResourceManager.GetString("ExtractGallery", resourceCulture);
}
}
///
- /// Looks up a localized string similar to Extract manually.
+ /// Looks up a localized string similar to Extracting....
///
- public static string ExtractManually {
+ public static string Extracting {
get {
- return ResourceManager.GetString("ExtractManually", resourceCulture);
+ return ResourceManager.GetString("Extracting", resourceCulture);
}
}
@@ -583,20 +583,20 @@ public static string ExplorerIntegration {
}
///
- /// Looks up a localized string similar to Extracting....
+ /// Looks up a localized string similar to Extract gallery.
///